<?php
namespace bptls_posttiles_namespace;

define( "BPTLS_ASFSK_ASSETS_PUBLIC_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/public" );
define( "BPTLS_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );
class Classbptlsposttiles {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function bptls_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'bptls_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function bptls_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'bptls_posttiles_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/post-tiles-w.php' );
	}

	public function bptls_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register WidgetsF
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\BPTLS_Post_Tiles());
	}

	// Register Category
	function bptls_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'bptls-posttiles-category',
			[
				'title' => esc_html__( 'Blog Post Tiles', 'blog-post-tiles' ),
				'icon' => 'eicon-person',
			]
		);
	}

	//css-js-link-here
	public function bptls_all_assets_for_the_public(){
		$all_css_file = array(
            'bptls-posttiles-plugin-main-one' => array('bptls_posttiles_css_path_define'=>'https://bwd-elementor-addons-pro.netlify.app/blog-post-tiles.css'),
        );
        foreach($all_css_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bptls_posttiles_css_path_define'], null, '2.1', 'all');
        }
	}

	//admin-icon
	public function bptls_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'bptls_posttiles_admin_main_css' => array('bptls_path_admin_define'=>BPTLS_ASFSK_ASSETS_ADMIN_DIR_FILE . '/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bptls_path_admin_define'], null, '2.1', 'all');
        }
	}
	
	public function __construct() {
		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'bptls_all_assets_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'bptls_all_assets_for_elementor_editor_admin']);
		
		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'bptls_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'bptls_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'bptls_admin_editor_scripts' ] );
	}
}

// Instantiate Plugin Class
Classbptlsposttiles::instance();